#[needs_env_var]Expand description
Skip compilation if the environment variable env_var is undefined or if its content does not
match the provided value.
#[needs_env_var]Skip compilation if the environment variable env_var is undefined or if its content does not
match the provided value.